@@ -231,8 +231,6 @@ class GoferHandler(HubOAuthenticated, tornado.web.RequestHandler):
     # @authenticated
     async def get(self):
         self.write("This is a post only page. You probably shouldn't be here!")
-        user = self.get_current_user()
-        self.write(json.dumps(user))
         self.finish()
 
     # @authenticated
@@ -276,8 +274,7 @@ class GoferHandler(HubOAuthenticated, tornado.web.RequestHandler):
 
             log_info_csv(user["name"], course, section, assignment, f"User logged in -  Using Referrer: {using_test_user}")
             # save notebook submission with user id and time stamp - this will be deleted
-            sub_timestamp = timestamp.replace(" ", "-").replace(",", "-").replace(":","-")
-            submission_file = f"/tmp/{user['name']}_{section}_{assignment}_{sub_timestamp}.ipynb"
+            submission_file = f"/tmp/{user['name']}_{section}_{assignment}_{timestamp}.ipynb"
             with open(submission_file, 'w', encoding="utf8") as outfile:
                 json.dump(notebook, outfile)
             save_submission(user['name'], course, section, assignment, notebook)
@@ -348,8 +345,7 @@ class GoferHandler(HubOAuthenticated, tornado.web.RequestHandler):
             log_error_csv(name, course, section, assignment, str(ex))
         finally:
             if os.path.exists(file_path):
-                print("will remove")
-                #os.remove(file_path)
+                os.remove(file_path)
 
 def get_timestamp():
     """
@@ -361,6 +357,9 @@ def get_timestamp():
     return date.strftime(date_format)[:-3]
 
 def write_logs(username, course, section, assignment, msg, trace, type, collection):
+    
+        
+    
     if os.getenv("VERBOSE_LOGGING") == "True" or type == "error":
         try:
             db = firestore.client()
@@ -394,10 +393,7 @@ def log_info_csv(username, course, section, assignment, msg):
     :param assignment: the assignment
     :param msg: optional message to logs
     """
-    try:
-        write_logs(username, course, section, assignment, msg, None, "info", f'{os.environ.get("ENVIRONMENT")}-logs')
-    except:
-        print("here")
+    write_logs(username, course, section, assignment, msg, None, "info", f'{os.environ.get("ENVIRONMENT")}-logs')
 
 def log_error_csv(username, course, section, assignment, msg):
     """
@@ -410,10 +406,7 @@ def log_error_csv(username, course, section, assignment, msg):
     :param assignment: the assignment
     :param msg: optional message to logs
     """
-    try:
-        write_logs(username, course, section, assignment, msg, str(traceback.format_exc()), "error", f'{os.environ.get("ENVIRONMENT")}-logs')
-    except:
-        print("here1")
+    write_logs(username, course, section, assignment, msg, str(traceback.format_exc()), "error", f'{os.environ.get("ENVIRONMENT")}-logs')
 
 def log_tornado_issues(msg, type):
     """
@@ -433,8 +426,7 @@ def log_tornado_issues(msg, type):
         }
         return db.collection(f'{os.environ.get("ENVIRONMENT")}-tornado-logs').add(data)
     except Exception as err:
-        #raise Exception(f"Error inserting {type} log into Google FireStore: {data}") from err
-        print("here 34")
+        raise Exception(f"Error inserting {type} log into Google FireStore: {data}") from err
 
 def save_submission(username, course, section, assignment, notebook):
     """
@@ -470,7 +462,7 @@ def sig_handler(server, sig, frame):
         log_tornado_issues(f'Will shutdown in {MAX_WAIT_SECONDS_BEFORE_SHUTDOWN} seconds ...', "info")
         stop_loop(time.time() + MAX_WAIT_SECONDS_BEFORE_SHUTDOWN)
 
-    log_tornado_issues('Caught signal: %s', sig, "warning")
+    log_tornado_issues(f'Caught signal: {sig}', "warning")
     io_loop.add_callback_from_signal(shutdown)
 
 def start_server():
@@ -507,6 +499,7 @@ def main():
     """
     try:
         start_server()
+        log_tornado_issues("Server starting", "info")
         tornado.ioloop.IOLoop.current().start()
     except Exception:
         log_tornado_issues("Server start up issues", "error")
